"""Interfaces for the Pilk Clicker API."""
from pilk_clicker.interfaces import auth
from pilk_clicker.interfaces import clicker
from pilk_clicker.interfaces import shop


__all__ = [
    "auth",
    "clicker",
    "shop",
]
