"""Modules for pilk_clicker."""
from pilk_clicker.modules.auth import Auth
from pilk_clicker.modules.clicker import Clicker
from pilk_clicker.modules.shop import Shop


__all__ = ["Clicker", "Auth", "Shop"]
