"""Interfaces for clicker module."""
from .clicker import IClickerDetailResponse
from .clicker import IClickerSaveRequest
from .clicker import IClickerSaveResponse
from .clicker import ITopListResponse


__all__ = [
    "IClickerDetailResponse",
    "IClickerSaveRequest",
    "IClickerSaveResponse",
    "ITopListResponse",
]
