"""Interfaces for shop module."""
from .shop import ISaveItemRequest
from .shop import ISaveItemResponse
from .shop import IShopUserResponse


__all__ = [
    "ISaveItemRequest",
    "ISaveItemResponse",
    "IShopUserResponse",
]
